@@ -10,6 +10,9 @@ import shutil
 import subprocess
 
 
+RESOURCES_DIR = os.path.abspath(os.path.join(__file__, '..', 'resources'))
+
+
 class Builder(object):
     implements(IBuilder)
 
@@ -25,9 +28,11 @@ class Builder(object):
             raise BuildTerminated('The build is already terminated.')
 
         path = os.path.join(self.build_directory, filename)
-        file_ = open(path, 'wb')
-        file_.write(data)
-        file_.close()
+        with open(path, 'wb') as fio:
+            if hasattr(data, 'read'):
+                shutil.copyfileobj(data, fio)
+            else:
+                fio.write(data)
 
     def build(self, latex):
         if self._terminated:
@@ -89,16 +94,35 @@ class Builder(object):
         latex_file.write(latex)
         latex_file.close()
 
-        stdout = ''
-        while self._rerun_required(stdout):
-            cmd = 'pdflatex --interaction=nonstopmode %s' % latex_path
-            exitcode_, stdout, stderr_ = self._execute(cmd)
+        self._run_pdflatex(latex_path)
+        if self._makeindex():
+            self._run_pdflatex(latex_path)
 
         if not os.path.exists(pdf_path):
             raise PDFBuildFailed('PDF missing.')
 
         return pdf_path
 
+    def _run_pdflatex(self, latex_path):
+        self._aux_data = None
+        cmd = 'pdflatex --interaction=nonstopmode %s' % latex_path
+        stdout = ''
+        while self._rerun_required(stdout):
+            _exitcode, stdout, _stderr = self._execute(cmd)
+
+    def _makeindex(self):
+        idx_path = os.path.join(self.build_directory, 'export.idx')
+        if not os.path.exists(idx_path):
+            return False
+
+        # When the makeindex arguments are too long, we might get a
+        # buffer oferflow.
+        # For avoiding this, we copy the "umlaut.ist" to the export directory.
+        umlaut_ist_path = os.path.join(RESOURCES_DIR, 'umlaut.ist')
+        shutil.copyfile(umlaut_ist_path, os.path.join(self.build_directory, 'umlaut.ist'))
+        self._execute('makeindex -g -s umlaut.ist export')
+        return True
+
     def _rerun_required(self, stdout):
         if self._rerun_limit == 0:
             raise PDFBuildFailed('Maximum pdf build limit reached.')
