@@ -1,16 +1,20 @@
 from ftw.pdfgenerator import interfaces
 from ftw.pdfgenerator.html2latex import wrapper
 from ftw.pdfgenerator.html2latex.patterns import DEFAULT_PATTERNS
+from ftw.pdfgenerator.html2latex.subconverters import footnote
 from ftw.pdfgenerator.html2latex.subconverters import htmlentities
 from ftw.pdfgenerator.html2latex.subconverters import hyperlink
 from ftw.pdfgenerator.html2latex.subconverters import listing
 from ftw.pdfgenerator.html2latex.subconverters import table
+from ftw.pdfgenerator.html2latex.subconverters import textformatting
+from ftw.pdfgenerator.html2latex.subconverters import url
 from ftw.pdfgenerator.utils import encode_htmlentities
 from ftw.pdfgenerator.utils import xml2htmlentities
 from random import choice
 from zope.component import adapts
 from zope.interface import implements, Interface
 import re
+import unicodedata
 
 
 PLACEHOLDERS = (
@@ -25,7 +29,10 @@ DEFAULT_SUBCONVERTERS = (
     table.TableConverter,
     listing.ListConverter,
     htmlentities.HtmlentitiesConverter,
-    hyperlink.HyperlinkConverter
+    hyperlink.HyperlinkConverter,
+    url.URLConverter,
+    textformatting.Textformatting,
+    footnote.FootnoteConverter,
     )
 
 
@@ -134,6 +141,15 @@ class HTML2LatexConverter(BasePatternAware):
         html = encode_htmlentities(text)
         return self.convert(html, **kwargs)
 
+    def quoted_umlauts(self, text):
+        if isinstance(text, str):
+            text = text.decode('utf-8')
+
+        text = unicodedata.normalize('NFD', text)
+        text = re.sub(ur'(.)\u0308', '"\g<1>', text, re.UNICODE)
+        text = unicodedata.normalize('NFC', text)
+
+        return text.encode('utf-8')
 
 
 class HTML2LatexConvertRunner(BasePatternAware):
@@ -190,7 +206,7 @@ class HTML2LatexConvertRunner(BasePatternAware):
             length = 10
 
         while not stop:
-            id_ = ''.join([choice(id_chars) for i in range(length)])
+            id_ = ''.join([choice(id_chars) for _i in range(length)])
             if id_ not in self.lockers.keys() and id_ not in self.html:
                 stop = True
 
@@ -226,10 +242,15 @@ class HTML2LatexConvertRunner(BasePatternAware):
         Unlocks previously locked HTML (see lockChars()). This method is
         automatically called by _convert() after converting HTML to Latex.
         """
+        html_before = self.html
+
         for id_ in self.lockers.keys():
             value = self.lockers[id_]
             self.html = self.html.replace(id_, value)
 
+        if html_before != self.html:
+            self._unlock_chars()
+
     def convert(self, html, custom_patterns=None, custom_subconverters=None,
                 trim=True):
         """Convert a sub-part of the HTML. This initializes another
@@ -289,6 +310,9 @@ class HTML2LatexConvertRunner(BasePatternAware):
         self._unlock_chars()
         return self.html
 
+    def quoted_umlauts(self, text):
+        return self.converter.quoted_umlauts(text)
+
     def _replace_regexp(self, search, replace, modifiers):
         xpr = re.compile(search, re.DOTALL)
         previous_html = ''
