@@ -4,6 +4,7 @@ from ftw.pdfgenerator.html2latex import subconverter
 from ftw.pdfgenerator.html2latex import wrapper
 from ftw.pdfgenerator.html2latex.utils import generate_manual_caption
 from ftw.pdfgenerator.utils import html2xmlentities
+from operator import methodcaller
 from xml.dom import minidom
 import re
 
@@ -38,6 +39,25 @@ HORIZONTAL_LAYOUT = BORDER_TABLE_T | BORDER_TABLE_B | \
     BORDER_CELL_T | BORDER_CELL_B
 
 
+def parse_html_style_attribute(value):
+    data = {}
+    if not value:
+        return data
+
+    for arg in value.split(';'):
+        arg = arg.strip()
+        if not arg:
+            continue
+
+        if ':' not in arg:
+            continue
+
+        key, value = arg.split(':', 1)
+        data[key.strip()] = value.strip()
+
+    return data
+
+
 class TableConverter(subconverter.SubConverter):
     """The TableConverter converts <table>-Tags to latex.
     """
@@ -55,17 +75,7 @@ class TableConverter(subconverter.SubConverter):
         self._environment = None
 
     def __call__(self):
-        html = self.get_html()
-        # cleanup html with BeautifulSoup
-
-        html = str(BeautifulSoup(html))
-        # minidom hates htmlentities, but loves xmlentities -.-
-
-        html = html2xmlentities(html)
-
-        # parse DOM
-        self.dom = minidom.parseString(html)
-        self.parse_dom()
+        self.parse()
 
         # render table
         latex = self.render()
@@ -78,6 +88,20 @@ class TableConverter(subconverter.SubConverter):
             self.converter.converter.layout.use_package('longtable')
         self.converter.converter.layout.use_package('multirow')
         self.converter.converter.layout.use_package('multicol')
+        # The "calc" package allows to use "length+length" inline.
+        self.converter.converter.layout.use_package('calc')
+
+    def parse(self):
+        html = self.get_html()
+        # cleanup html with BeautifulSoup
+        html = str(BeautifulSoup(html, fromEncoding='utf-8'))
+        # minidom hates htmlentities, but loves xmlentities -.-
+
+        html = html2xmlentities(html)
+
+        # parse DOM
+        self.dom = minidom.parseString(html)
+        self.parse_dom()
 
     @property
     def environment(self):
@@ -120,11 +144,12 @@ class TableConverter(subconverter.SubConverter):
 
     def render(self):
         latex = [
-            r'\makeatletter\@ifundefined{tablewidth}{' + \
-                r'\newlength\tablewidth}\makeatother',
+            r'\makeatletter\@ifundefined{tablewidth}{' +
+            r'\newlength\tablewidth}\makeatother',
             r'\setlength\tablewidth\linewidth',
             r'\addtolength\tablewidth{-%i\tabcolsep}' % (
-                2 * len(self.columns))]
+                2 * len(self.columns)),
+            r'\renewcommand{\arraystretch}{1.4}']
 
         caption_command, insert_caption_at_top = self.render_caption()
         if caption_command and insert_caption_at_top:
@@ -134,7 +159,8 @@ class TableConverter(subconverter.SubConverter):
         latex.append(r'\begin{%s}{%s}' % (
                 self.environment, self.get_table_format()))
         latex.append(self.render_rows().strip())
-        latex.append(r'\end{%s}' % self.environment)
+        latex.append(r'\end{%s}\\' % self.environment)
+        latex.append(r'\vspace{4pt}')
 
         if caption_command and not insert_caption_at_top:
             latex.append(r'\vspace{-\baselineskip}')
@@ -149,7 +175,7 @@ class TableConverter(subconverter.SubConverter):
 
         for row in self.rows:
             rowLatex = row.render()
-            if row.contains_head_cells():
+            if row.is_head_row():
                 head_rows.append(rowLatex)
             else:
                 body_rows.append(rowLatex)
@@ -177,29 +203,49 @@ class TableConverter(subconverter.SubConverter):
         the table.
         """
 
-        caption = self.dom.getElementsByTagName('caption')
-        if len(caption) > 0:
-            caption_tag = caption[0]
-            siblings = caption_tag.parentNode.childNodes
-            insert_at_top = len(siblings) / float(2) > (
-                siblings.index(caption_tag) + 1)
+        caption, insert_at_top = self._get_caption_from_tag()
 
-            content = ''.join([child.toxml() for child
-                               in caption[0].childNodes])
+        if caption is None:
+            caption, insert_at_top = self._get_caption_from_summary()
 
-            content = content.encode('utf8')
-            latexContent = self.converter.convert(content)
-
-            show_in_index = 'notListed' not in self.get_css_classes()
-
-            latex = generate_manual_caption(latexContent, 'table',
-                                            show_in_index=show_in_index)
-
-            return latex, insert_at_top
-
-        else:
+        if caption is None:
             return None, False
 
+        show_in_index = 'notListed' not in self.get_css_classes()
+
+        latex = generate_manual_caption(caption, 'table',
+                                        show_in_index=show_in_index)
+
+        return latex, insert_at_top
+
+    def _get_caption_from_tag(self):
+        caption_tags = self.dom.getElementsByTagName('caption')
+        if len(caption_tags) == 0:
+            return None, False
+
+        caption_tag = caption_tags[0]
+
+        content = ''.join([child.toxml() for child
+                           in caption_tag.childNodes])
+        content = content.encode('utf8')
+        latexContent = self.converter.convert(content)
+
+        siblings = caption_tag.parentNode.childNodes
+        insert_at_top = len(siblings) / float(2) > (
+            siblings.index(caption_tag) + 1)
+
+        return latexContent, insert_at_top
+
+    def _get_caption_from_summary(self):
+        domTable = self.dom.getElementsByTagName('table')[0]
+
+        caption = domTable.getAttribute('summary') or None
+        if caption is not None:
+            caption = self.converter.convert(caption)
+
+        insert_at_top = False
+        return caption, insert_at_top
+
     def get_table_format(self):
         column_format = []
         for col in self.columns:
@@ -210,7 +256,7 @@ class TableConverter(subconverter.SubConverter):
         # create colum objects
         dom_col_list = self.dom.getElementsByTagName('col')
         amount = self.get_amount_of_columns()
-        amount = amount > len(dom_col_list) and amount or len(dom_col_list)
+        amount = amount and amount or len(dom_col_list)
 
         for c in range(amount):
             col = self.create_latex_column()
@@ -224,9 +270,9 @@ class TableConverter(subconverter.SubConverter):
             }
 
         for domTr in self.dom.getElementsByTagName('tr'):
-            self._parse_tr_dom(domTr, multi_row_cache)
+            self._parse_tr_dom(domTr, multi_row_cache, amount)
 
-    def _parse_tr_dom(self, domTr, multi_row_cache):
+    def _parse_tr_dom(self, domTr, multi_row_cache, amount_of_columns):
         row = self.create_latex_row(domTr=domTr)
         self.rows.append(row)
 
@@ -240,7 +286,8 @@ class TableConverter(subconverter.SubConverter):
         columnIndex = 0
         cell_index = 0
 
-        while len(cells) > cell_index:
+        while sum(map(methodcaller('get_colspan'), row.cells)) < \
+                amount_of_columns:
             if columnIndex in multi_row_cache.keys():
                 multi_row_cache[columnIndex][0].register_row(row)
                 multi_row_cache[columnIndex][1] -= 1
@@ -249,7 +296,10 @@ class TableConverter(subconverter.SubConverter):
                 columnIndex += 1
 
             else:
-                dom_cell = cells[cell_index]
+                try:
+                    dom_cell = cells[cell_index]
+                except IndexError:
+                    break
                 cell_index += 1
                 cell = self.create_latex_cell(dom_cell=dom_cell, row=row)
                 # rowspan?
@@ -277,16 +327,6 @@ class TableConverter(subconverter.SubConverter):
 
     def get_amount_of_columns(self):
         columns = 0
-        # by <colgroup>-Tag
-        colgroups = self.dom.getElementsByTagName('colgroup')
-        if len(colgroups) > 0:
-            colgroup = colgroups[0]
-            for col in colgroup.getElementsByTagName('col'):
-                try:
-                    columns += int(col.getAttribute('colspan'))
-                except (ValueError, TypeError):
-                    columns += 1
-
         # by <td>- and <th>-Tags
         for tr in self.dom.getElementsByTagName('tr'):
             tr_columns = 0
@@ -419,11 +459,11 @@ class LatexRow(object):
     def register_cell(self, cell):
         self.cells.append(cell)
 
-    def contains_head_cells(self):
+    def is_head_row(self):
         for cell in self.cells:
-            if cell.is_head_cell():
-                return True
-        return False
+            if not cell.is_head_cell():
+                return False
+        return True
 
     def is_first_row(self):
         return self.table_converter.rows.index(self) == 0
@@ -456,7 +496,6 @@ class LatexRow(object):
         line_latex = self.get_horizontal_line_latex(self.get_next_row(), self)
         if line_latex:
             latex.append(line_latex)
-
         return '\n'.join(latex) + '\n'
 
     def get_horizontal_line_latex(self, top_row, bottom_row):
@@ -589,18 +628,6 @@ class LatexCell(object):
         latex = self.converter.convert(content,
                                        custom_patterns=custom_patterns)
 
-        if self.get_calculated_width() and self.get_align():
-            # if a width and align is defined, we need to set
-            # aligenement in content part with a command
-            mapping = {
-                'left': r'\raggedright ',
-                'right': r'\raggedleft ',
-                'center': r'\center\vspace{-1.5em}',
-                }
-
-            if self.get_align() in mapping.keys():
-                latex = mapping[self.get_align()] + latex
-
         if 'grey' in self.get_css_classes():
             self.converter.converter.layout.use_package('xcolor')
             latex = r'\textcolor{gray}{%s}' % latex
@@ -614,6 +641,18 @@ class LatexCell(object):
         if 'bold' in self.get_css_classes() or self.is_head_cell():
             latex = r'\textbf{%s}' % latex
 
+        if self.get_calculated_width() and self.get_align():
+            # if a width and align is defined, we need to set
+            # aligenement in content part with a command
+            mapping = {
+                'left': r'\raggedright ',
+                'right': r'\raggedleft ',
+                'center': r'\centering ',
+                }
+
+            if self.get_align() in mapping.keys():
+                latex = mapping[self.get_align()] + latex
+
         if 'indent2' in self.get_css_classes():
             latex = r'\hangindent 0.2cm\hspace{0.2cm} %s' % latex
         elif 'indent10' in self.get_css_classes():
@@ -655,11 +694,25 @@ class LatexCell(object):
 
     def get_width(self):
         if self._width == _marker:
-            try:
-                self._width = LatexWidth.convert(
-                    self.dom_cell.getAttribute('width'))
-            except ValueError:
-                self._width = None
+            widths = [
+                parse_html_style_attribute(
+                    self.dom_cell.getAttribute('style')).get('width', ''),
+                self.dom_cell.getAttribute('width'),
+                ]
+
+            self._width = None
+
+            for width in widths:
+                if not width:
+                    continue
+
+                try:
+                    self._width = LatexWidth.convert(width)
+                except ValueError:
+                    continue
+                else:
+                    break
+
         return self._width
 
     def get_colspan(self):
@@ -693,6 +746,9 @@ class LatexCell(object):
                 except (TypeError, ValueError):
                     # one of the columns has no or invalid width (not addable)
                     return None
+            # Compensate padding of spanned columns
+            padding = r'%i\tabcolsep' % (2 * (len(self.columns) - 1))
+            width = '+'.join((str(width), padding))
             return width
 
     def get_align(self):
@@ -830,6 +886,11 @@ class LatexWidth(object):
         creates a LatexWidth object by a HTML width-Attribute
         """
 
+        # px is the same as no measure unit, so we can strip it.
+        width = width.strip()
+        if width.endswith('px'):
+            width = width.rstrip('px')
+
         # absolute
         for unit in cls.VALID_ABSOLUTE_UNITS:
             match = re.compile('^([0-9,\.]{1,})(%s)$' % unit).match(width)
@@ -884,8 +945,8 @@ class LatexWidth(object):
 
         if a.unit != b.unit:
             raise ValueError(
-                'Cannot accumulate LatexWidths with different ' + \
-                    'units (%s, %s)' % (a.unit, b.unit))
+                'Cannot accumulate LatexWidths with different ' +
+                'units (%s, %s)' % (a.unit, b.unit))
 
         return LatexWidth(width=(a.width + b.width),
                           type_=a.type,
@@ -924,7 +985,6 @@ def apply_borders_to_format(element, format_):
     `element` -- Cell or column object.
     `format_` -- LaTeX format definiton.
     """
-
     if element.has_left_border() and not format_.startswith('|'):
         format_ = '|%s' % format_
 
